@@ -51,7 +51,7 @@ void FileDownloadHelper::start()
     const QString file_name = QFileInfo(path_).fileName();
     const QString dirent_path = ::getParentPath(path_);
     req_ = new GetDirentsRequest(account_, repo_.id, dirent_path);
-    connect(req_, SIGNAL(success(bool, const QList<SeafDirent> &)),
+    connect(req_, SIGNAL(success(bool, const QList<SeafDirent> &, const QString&)),
             this, SLOT(onGetDirentsSuccess(bool, const QList<SeafDirent> &)));
     connect(req_, SIGNAL(failed(const ApiError &)),
             this, SLOT(onGetDirentsFailure(const ApiError &)));
