@@ -32,6 +32,7 @@ extern "C" {
 #include "api/commit-details.h"
 #include "sync-errors-dialog.h"
 #include "account-mgr.h"
+#include "filebrowser/progress-dialog.h"
 
 #include "tray-icon.h"
 #if defined(Q_OS_MAC)
@@ -107,7 +108,6 @@ private:
     const QString previous_commit_id_;
 };
 
-
 } // namespace
 
 SeafileTrayIcon::SeafileTrayIcon(QObject *parent)
@@ -117,7 +117,8 @@ SeafileTrayIcon::SeafileTrayIcon(QObject *parent)
       state_(STATE_DAEMON_UP),
       next_message_msec_(0),
       sync_errors_dialog_(nullptr),
-      about_dialog_(nullptr)
+      about_dialog_(nullptr),
+      log_dir_uploader_(nullptr)
 {
     setState(STATE_DAEMON_DOWN);
     rotate_timer_ = new QTimer(this);
@@ -183,6 +184,10 @@ void SeafileTrayIcon::createActions()
     open_log_directory_action_->setStatusTip(tr("open %1 log folder").arg(getBrand()));
     connect(open_log_directory_action_, SIGNAL(triggered()), this, SLOT(openLogDirectory()));
 
+    upload_log_directory_action_ = new QAction(tr("Upload log files"), this);
+    upload_log_directory_action_->setStatusTip(tr("upload %1 log files").arg(getBrand()));
+    connect(upload_log_directory_action_, SIGNAL(triggered()), this, SLOT(uploadLogDirectory()));
+
     show_sync_errors_action_ = new QAction(tr("Show file sync errors"), this);
     show_sync_errors_action_->setStatusTip(tr("Show file sync errors"));
     connect(show_sync_errors_action_, SIGNAL(triggered()), this, SLOT(showSyncErrorsDialog()));
@@ -207,6 +212,7 @@ void SeafileTrayIcon::createContextMenu()
     context_menu_->addAction(open_seafile_folder_action_);
     context_menu_->addAction(settings_action_);
     context_menu_->addAction(open_log_directory_action_);
+    //context_menu_->addAction(upload_log_directory_action_);
     context_menu_->addAction(show_sync_errors_action_);
     // context_menu_->addMenu(help_menu_);
     context_menu_->addSeparator();
@@ -257,6 +263,7 @@ void SeafileTrayIcon::createGlobalMenuBar()
     global_menu_->addAction(open_seafile_folder_action_);
     global_menu_->addAction(settings_action_);
     global_menu_->addAction(open_log_directory_action_);
+    //global_menu_->addAction(upload_log_directory_action_);
     global_menu_->addAction(show_sync_errors_action_);
     global_menu_->addSeparator();
     global_menu_->addAction(enable_auto_sync_action_);
@@ -534,6 +541,25 @@ void SeafileTrayIcon::openLogDirectory()
     QDesktopServices::openUrl(QUrl::fromLocalFile(log_path));
 }
 
+void SeafileTrayIcon::uploadLogDirectory()
+{
+    if (!seafApplet->accountManager()->currentAccount().isValid()) {
+        seafApplet->warningBox(tr("Please login first"));
+        return;
+    }
+
+    if (log_dir_uploader_ == nullptr) {
+        log_dir_uploader_ = new LogDirUploader();
+        connect(log_dir_uploader_, SIGNAL(finished()), this, SLOT(clearUploader()));
+        log_dir_uploader_->start();
+    }
+}
+
+void SeafileTrayIcon::clearUploader()
+{
+    log_dir_uploader_ = nullptr;
+}
+
 void SeafileTrayIcon::showSettingsWindow()
 {
     seafApplet->settingsDialog()->show();
