@@ -5,6 +5,10 @@
 #include <QHash>
 #include <QQueue>
 
+#include "account.h"
+#include "log-uploader.h"
+
+class ApiError;
 class QAction;
 class QMenu;
 class QMenuBar;
@@ -12,9 +16,7 @@ class QMenuBar;
 class TrayNotificationManager;
 #endif
 class AboutDialog;
-
 class SyncErrorsDialog;
-
 class SeafileTrayIcon : public QSystemTrayIcon {
     Q_OBJECT
 
@@ -63,8 +65,10 @@ private slots:
     void openHelp();
     void openSeafileFolder();
     void openLogDirectory();
+    void uploadLogDirectory();
     void about();
     void checkTrayIconMessageQueue();
+    void clearUploader();
 
     // only used on windows
     void onMessageClicked();
@@ -95,6 +99,7 @@ private:
     QAction *settings_action_;
     QAction *open_seafile_folder_action_;
     QAction *open_log_directory_action_;
+    QAction *upload_log_directory_action_;
     QAction *show_sync_errors_action_;
 
     QAction *about_action_;
@@ -134,6 +139,7 @@ private:
 
     SyncErrorsDialog *sync_errors_dialog_;
     AboutDialog *about_dialog_;
+    LogDirUploader *log_dir_uploader_;
 };
 
 #endif // SEAFILE_CLIENT_TRAY_ICON_H
